@@ -11,9 +11,9 @@ class ErdAdvantiumMicrowaveMinMaxConverter(ErdReadOnlyConverter[ErdAdvantiumMicr
 
         return ErdAdvantiumMicrowaveMinMax(
             is_valid=True,
-            min_time=erd_decode_timespan_seconds(value[0:4]),
-            max_time=erd_decode_timespan_seconds(value[4:8]),
-            slow_cook_min_time=erd_decode_timespan_seconds(value[8:12]),
-            slow_cook_max_time=erd_decode_timespan_seconds(value[12:16]),
+            min_time=erd_decode_timespan(value[0:4], uom="seconds"),
+            max_time=erd_decode_timespan(value[4:8], uom="seconds"),
+            slow_cook_min_time=erd_decode_timespan(value[8:12], uom="seconds"),
+            slow_cook_max_time=erd_decode_timespan(value[12:16], uom="seconds"),
             raw_value=value
         )
\ No newline at end of file
