@@ -18,3 +18,5 @@ from .erd_precision_cooking_probe_battery_status import ErdPrecisionCookingProbe
 from .erd_precision_cooking_start_sous_vide_timer_active_status import ErdPrecisionCookingStartSousVideTimerActiveStatus
 from .erd_precision_cooking_probe_target_time_reached import ErdPrecisionCookingProbeTargetTimeReached
 from .erd_precision_cooking_app_probe_control_mode import ErdPrecisionCookingAppProbeControlMode
+from .erd_oven_light_level_availability import ErdOvenLightLevelAvailability
+from .erd_oven_light_level import ErdOvenLightLevel
\ No newline at end of file
